%define upstream_name    OpenGL
%define upstream_version 0.7004

%{?perl_default_filter}

Name:       perl-%{upstream_name}
Version:    %perl_convert_version %{upstream_version}
Release:    %mkrel 2

Summary:    Interface to OpenGL drawing/imaging library
License:    GPL+ or Artistic
Group:      Development/Perl
Url:        https://metacpan.org/release/%{upstream_name}
Source0:    https://cpan.metacpan.org/modules/by-module//%{upstream_name}-%{upstream_version}.tar.gz
# Patch from Fedora
Patch1:     0001-Don-t-check-current-display-for-extensions.patch

BuildRequires: perl(ExtUtils::MakeMaker)
BuildRequires: perl(Test::More)
BuildRequires: pkgconfig(freeglut)
BuildRequires: pkgconfig(xi)
BuildRequires: mesagl-devel
BuildRequires: pkgconfig(glu)
BuildRequires: perl-devel
BuildRequires: pkgconfig(xmu)
BuildRequires: x11-server-xvfb
Conflicts:     perl-OpenGL-GLUT

%description
Naming convention:
    Virtually all of the OpenGL 1.0, and 1.1 functions are available, and
    most of 1.2. In general, the calling sequence is identical in Perl as
    in C.

    Most functions that have no pointer arguments are called identically in
    Perl as in C, and the same name is used.

    Functions that use Perl array arguments and have been changed in "the
    obvious way" -- to take a variable number of arguments and/or to return
    an array -- have the the same names as their C counterparts, but with a
    _p suffix.

%prep
%setup -q -n %{upstream_name}-%{upstream_version}
%patch -P 1 -p1
# test.pl requires interaction, prefer using tests in t/
rm test.pl

%build
%__perl Makefile.PL INSTALLDIRS=vendor dist=NO_EXCLUSIONS
sed 's/PERL_DL_NONLAZY=1//' -i Makefile
make

%install
%make_install

%check
# t/shader.t needs a DISPLAY
xvfb-run make test

%files
%doc Changes COPYRIGHT INSTALL META.yml README SUPPORTS TODO examples
%{_mandir}/man3/*
%{perl_vendorarch}/*


%changelog
* Fri Mar 21 2025 tv <tv> 0.700.400-2.mga10
+ Revision: 2168253
- Conflicts with perl-OpenGL-GLUT which was added back in

* Fri Mar 21 2025 tv <tv> 0.700.400-1.mga10
+ Revision: 2168226
- update to 0.7004

* Wed Mar 12 2025 tv <tv> 0.700.200-1.mga10
+ Revision: 2163105
- update to 0.7002

* Sun Dec 22 2024 pterjan <pterjan> 0.700.0-14.mga10
+ Revision: 2128044
- Rebuild for patchN deprecation

* Thu Aug 22 2024 neoclust <neoclust> 0.700.0-13.mga10
+ Revision: 2088185
- Rebuild against new perl

* Wed Nov 29 2023 tv <tv> 0.700.0-12.mga10
+ Revision: 2011362
- Rebuild for perl-5.38

* Tue Jun 07 2022 umeabot <umeabot> 0.700.0-11.mga9
+ Revision: 1862246
- Rebuild for Perl 5.36

* Wed Mar 30 2022 umeabot <umeabot> 0.700.0-10.mga9
+ Revision: 1835566
- Mageia 9 Mass Rebuild

* Mon May 24 2021 umeabot <umeabot> 0.700.0-9.mga9
+ Revision: 1726961
- Rebuild for perl 5.34

* Wed Jun 17 2020 umeabot <umeabot> 0.700.0-8.mga8
+ Revision: 1595128
- Rebuild for perl 5.32

* Sat Feb 15 2020 umeabot <umeabot> 0.700.0-7.mga8
+ Revision: 1529128
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%makeinstall_std

* Tue Aug 27 2019 tv <tv> 0.700.0-6.mga8
+ Revision: 1433120
- rebuild with perl-5.30

* Fri Sep 21 2018 umeabot <umeabot> 0.700.0-5.mga7
+ Revision: 1293611
- Mageia 7 Mass Rebuild

* Wed Aug 08 2018 pterjan <pterjan> 0.700.0-4.mga7
+ Revision: 1249864
- Rebuild for perl 5.28

* Tue Oct 03 2017 tv <tv> 0.700.0-3.mga7
+ Revision: 1166079
- rebuild with fixed rpm for missing autodeps

* Thu Aug 31 2017 pterjan <pterjan> 0.700.0-2.mga7
+ Revision: 1149893
- Rebuild for perl ABI changes

* Fri Jul 28 2017 shlomif <shlomif> 0.700.0-1.mga7
+ Revision: 1132204
- New version 0.70

* Sat Jul 22 2017 neoclust <neoclust> 0.670.400-5.mga7
+ Revision: 1127595
- Rebuild against new Perl 5.26

* Sun Jun 19 2016 pterjan <pterjan> 0.670.400-4.mga6
+ Revision: 1031543
- Rebuild for perl 5.22.2

* Fri Feb 12 2016 umeabot <umeabot> 0.670.400-3.mga6
+ Revision: 957825
- Mageia 6 Mass Rebuild

* Fri Jun 26 2015 tv <tv> 0.670.400-2.mga6
+ Revision: 845063
- rebuild for soname-ifed perl

* Wed Jun 24 2015 sander85 <sander85> 0.670.400-1.mga6
+ Revision: 841830
- update to 0.6704

* Thu Oct 23 2014 pterjan <pterjan> 0.670.300-6.mga5
+ Revision: 792675
- Rebuild to fix broken dependencies

* Sat Oct 18 2014 umeabot <umeabot> 0.670.300-5.mga5
+ Revision: 787997
- Rebuild to potentially add missing dependencies

* Wed Oct 15 2014 umeabot <umeabot> 0.670.300-4.mga5
+ Revision: 742865
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 0.670.300-3.mga5
+ Revision: 725868
- use %%perl_default_filter (fix excludes)

* Tue Sep 16 2014 umeabot <umeabot> 0.670.300-2.mga5
+ Revision: 685792
- Mageia 5 Mass Rebuild

* Wed Jun 04 2014 sander85 <sander85> 0.670.300-1.mga5
+ Revision: 632872
- update to 0.6703

* Tue Jun 03 2014 pterjan <pterjan> 0.670.0-3.mga5
+ Revision: 631532
- Rebuild for perl 5.20

* Mon Oct 21 2013 umeabot <umeabot> 0.670.0-2.mga4
+ Revision: 537401
- Mageia 4 Mass Rebuild

* Thu Sep 26 2013 sander85 <sander85> 0.670.0-1.mga4
+ Revision: 486903
- update to 0.67

* Wed May 29 2013 jquelin <jquelin> 0.660.0-5.mga4
+ Revision: 430924
- perl 5.18.0 rebuild

* Sun Jan 13 2013 umeabot <umeabot> 0.660.0-4.mga3
+ Revision: 371132
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed May 30 2012 jquelin <jquelin> 0.660.0-3.mga3
+ Revision: 251003
- rebuild for perl 5.16

* Mon Feb 13 2012 dmorgan <dmorgan> 0.660.0-2.mga2
+ Revision: 208373
- mesaglw-devel does not exist anymore, so remove from buildrequires
+ jquelin <jquelin>
- update to 0.66
- adding missing buildrequires:
- bug#2412
- bug#2412 - change glut requires to freeglut
- update to 0.65

* Sun Jun 12 2011 sander85 <sander85> 0.640.0-2.mga2
+ Revision: 104388
- Rebuild for perl 5.14

* Sat Jan 22 2011 jquelin <jquelin> 0.640.0-1.mga1
+ Revision: 30995
- mageia rebuild
- imported package perl-OpenGL

